@@ -333,14 +333,17 @@ def products_related_data(url_images, url_produits, each_picture, url_product, u
                            "path": path,
                            "customer_name": customer_name,
                            "customer_type": customer_type,
-                           "project_name": project_name})
+                           "project_name": project_name,
+                           "product_id": product_id,
+                           "product_url_mobile": url_mobile_product})
 
 
 def download_commit_db_images(url_images, url_produits):
     if url_images:
         for image in url_images:
             try:
-                download_or_remove(image.get('images', ''), "", "", "", image.get("customer_name"),
+                download_or_remove(image.get('images', ''), "", image.get("product_id", ),
+                                   image.get("product_url_mobile", ""), image.get("customer_name"),
                                    image.get('customer_type'), image.get('path'), image.get('project_name'))
             except Exception as e:
                 logger.error(
@@ -377,7 +380,7 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
         extention = image_extension(url)
         filename = hash_file + '.' + extention
         fichier = path_out + '/' + filename
-        # logger.info("Retrieving image from URL...")
+        logger.info("Retrieving image from URL...")
 
         db.create_client_products_table(replace_special_caractere(customer_name).replace(' ', '_'))
 
@@ -387,9 +390,9 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
             logger.info("File exists but size is 0... Download again!")
             start = time.process_time()
             download_resized_image(url, fichier)
-            # logger.info("*** download time taken" + str(time.process_time() - start))
+            logger.info("*** download time taken" + str(time.process_time() - start))
         else:
-            # logger.info("File doesn't exist... Downloading...")
+            logger.info("File doesn't exist... Downloading...")
             download_resized_image(url, fichier)
         if fichier.split('/')[-2] == project_name:
             file_azure = input_azure + fichier.split('/')[-1]
@@ -398,7 +401,7 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
         upload_file(file_local_path=fichier, file_upload_s3=input_s3 + fichier.split('/')[-2] + '/',
                     file_upload_azure=file_azure)
 
-        hash_files = hash_files + filename + " "
+        hash_files = hash_files + hash_file + " "
         data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'),
                                               each_url_product,
                                               project_name)
@@ -427,12 +430,13 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
 
         if each_url_product == '':
             db.add_or_update_images(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
-                                    reference=urls, urlProduit="", product_id="", hash_code=hash_files,
-                                    project_name=project_name)
+                                    reference=urls, urlProduit="", product_id=product_id,
+                                    hash_code=hash_files, project_name=project_name,
+                                    product_mobile_url=product_url_mobile)
         else:
             db.add_or_update_products(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
                                       reference=urls, urlProduit=each_url_product, product_id=product_id,
-                                   product_url_mobile=product_url_mobile, hash_code=hash_files, project_name=project_name, update=data_product)
+                                      product_url_mobile=product_url_mobile, hash_code=hash_files, project_name=project_name, update=data_product)
 
 
 def get_client_ip(request_client):
@@ -527,7 +531,7 @@ def max_number_product_exceeded(customer_name, customer_type, body):
             somme = 0
             for category in body.json()[customer_name + '_' + customer_type]:
                 somme += len(category['Photos'])
-            # logger.info("products count %s for file %s client %s type %s" % (somme, body, customer_name, customer_type))
+            logger.info("products count %s for file %s client %s type %s" % (somme, body, customer_name, customer_type))
             if somme > max_number_training_image and plan_name == 'FREE':
                 return True
             else:
@@ -555,7 +559,7 @@ def get_count_product_validation(token, url_shop, plan):
     max_images_training = db.get_plan_form_name(plan)[4]
     count_json = json.loads(count_products.text)
     counter = count_json.get('count', 0)
-    if counter > max_images_training or counter == 0:
+    if (counter > max_images_training or counter == 0) and plan == 'FREE':
         return False
     else:
         return True
