@@ -389,7 +389,7 @@ def get_client_statistics(customer_name, customer_type):
     response4 = scores_repartition_per_users(customer_name, customer_type)
     number_request_week = number_request_by_week(customer_name, customer_type)
     user_progress_requests = [get_counter_of_last_four_months(customer_name, customer_type)[1],
-                            get_counter_of_last_four_months(customer_name, customer_type)[2]]
+                              get_counter_of_last_four_months(customer_name, customer_type)[2]]
     requests_four_last_months = []
     for i in range(0, len(response1)):
         requests_four_last_months.append({"month": response1[i][0], "number": response1[i][1]})
@@ -416,15 +416,11 @@ def get_client_statistics(customer_name, customer_type):
 
     customer_plan = db.get_client_payment(customer_name, customer_type)
     if customer_plan[5] == 'FREE':
-        number_of_requests_allowed = ALLOWED_REQUESTS_FREE
-    elif customer_plan[5] == 'STANDARD':
-        number_of_requests_allowed = ALLOWED_REQUESTS_STANDARD
-    elif customer_plan[5] == 'PREMIUM':
-        number_of_requests_allowed = ALLOWED_REQUESTS_PREMIUM
+        number_of_requests_allowed = 1000
     else:
-        number_of_requests_allowed = ALLOWED_REQUESTS_PLATINUM
+        number_of_requests_allowed = 1000000
 
-    request_total= sum(nbr_request_total_current_month)
+    request_total = sum(nbr_request_total_current_month)
     request_number_progress.append({"number_of_requests_used": request_total,
                                     "number_of_requests_allowed": number_of_requests_allowed})
 
@@ -434,7 +430,6 @@ def get_client_statistics(customer_name, customer_type):
     user_progress_requests_per_period['user_progress_requests_last_3_month_ago'] = user_progress_requests[1]
     progression.append(user_progress_requests_per_period)
 
-
     result = {
         'number_of_requests_for_the_four_last_months': requests_four_last_months,
         'request_repartition': request_by_country,
@@ -702,12 +697,8 @@ def customer_registration(customer_email, customer_type, customer_name, customer
         db.create_plans_table()
         if plan == "FREE":
             db.update_client_payement(customer_name, customer_type, date, plan, 0, "stripe", 0)
-        elif plan == "STANDARD":
-            db.update_client_payement(customer_name, customer_type, date, plan, 0, "stripe", 99 * 11)
-        elif plan == "PREMIUM":
-            db.update_client_payement(customer_name, customer_type, date, plan, 0, "stripe", 299 * 11)
         else:
-            db.update_client_payement(customer_name, customer_type, date, plan, 0, "stripe", 499 * 11)
+            db.update_client_payement(customer_name, customer_type, date, plan, 0, "stripe", 99)
 
         db.add_update_client_parameter(customer_name, customer_type)
 
@@ -746,7 +737,6 @@ def contact(first_name, customer_email, subject_of_email, message_email):
         server.sendmail(fromaddr, ADMIN_EMAIL, msg.as_string())
         return True
     except Exception as e:
-
         logger.error("exception ......" + str(e))
         return False
 
@@ -1025,7 +1015,7 @@ def can_create_users_api(customerEmail, permission, type_user_admin, type_new_us
                                     force_bytes(customer[0])).decode('utf-8') \
                                            + '/' + customer[12]
 
-                            send_inscription_email(customer_email=email, full_url=full_url, password_client=password)
+                            send_inscription_email(email, full_url, password)
                             msg = email + "##" + type_new_user + "##" + entreprise + "##" + domaine
                         else:
                             msg = "Email already in use"
@@ -1041,7 +1031,7 @@ def can_create_users_api(customerEmail, permission, type_user_admin, type_new_us
                                                expiration_duration_in_hours=720, type=type_new_user)
                         if test:
                             db.commit_db_changes()
-                            send_inscription_email(customer_email=email, full_url="", password_client=password)
+                            send_inscription_email(email, "", password)
 
                             msg = email + "##" + type_new_user + "##" + entreprise + "##" + domaine
                         else:
@@ -1065,7 +1055,7 @@ def can_create_users_api(customerEmail, permission, type_user_admin, type_new_us
                                                expiration_duration_in_hours=720, type=type_new_user)
                         if test:
                             db.commit_db_changes()
-                            send_inscription_email(customer_email=email, full_url="", password_client=password)
+                            send_inscription_email(email, "", password)
                             msg = email + "##" + type_new_user + "##" + entreprise + "##" + domaine
                         else:
                             msg = "Email already in use"
@@ -1113,7 +1103,7 @@ def can_edit_users_api(customerEmail, permission, type_user_admin, email, passwo
                                     force_bytes(customer[0])).decode('utf-8') \
                                            + '/' + customer[12]
 
-                            send_inscription_email(customer_email=email, full_url=full_url, password_client=password)
+                            send_inscription_email(email, full_url, password)
                             msg = email + "##" + type_edit_user + "##" + entreprise + "##" + domaine
                         else:
                             msg = "Email not found"
@@ -1126,8 +1116,7 @@ def can_edit_users_api(customerEmail, permission, type_user_admin, email, passwo
                                                   password=hash_password,customer=entreprise, domaine=domaine)
 
                         if test:
-                            send_inscription_email(customer_email=email, full_url="",
-                                                   password_client=password)
+                            send_inscription_email(email, "", password)
 
                             msg = email + "##" + type_edit_user + "##" + entreprise + "##" + domaine
                         else:
@@ -1152,8 +1141,7 @@ def can_edit_users_api(customerEmail, permission, type_user_admin, email, passwo
                                                   password=hash_password,customer=entreprise, domaine=domaine)
 
                         if test is True:
-                            send_inscription_email(customer_email=email, full_url="",
-                                                   password_client=password)
+                            send_inscription_email(email, "", password)
 
                             msg = email + "##" + type_edit_user + "##" + entreprise + "##" + domaine
                         else:
