@@ -1,42 +1,11 @@
 #!/usr/bin/env python
 from foqus.configuration import *
 
-import coloredlogs
-import logging
 import pika
 import threading
 import uuid
 
-if USE_LOG_AZURE:
 
-    from azure_storage_logging.handlers import TableStorageHandler
-
-    # configure the handler and add it to the logger
-    logger = logging.getLogger(__name__)
-    handler = TableStorageHandler(account_name=LOG_AZURE_ACCOUNT_NAME,
-                                  account_key=LOG_AZURE_ACCOUNT_KEY,
-                                  extra_properties=('%(hostname)s',
-                                                    '%(levelname)s'))
-    logger.setLevel(logging.DEBUG)
-    logger.addHandler(handler)
-else:
-
-    logger = logging.getLogger(__name__)
-    coloredlogs.install()
-    logger.setLevel(logging.DEBUG)
-    # create file handler which logs even debug messages
-    fh = logging.FileHandler(LOG_PATH + 'trynfit_debug.log')
-    fh.setLevel(logging.DEBUG)
-    # create console handler with a higher log level
-    ch = logging.StreamHandler()
-    ch.setLevel(logging.ERROR)
-    # create formatter and add it to the handlers
-    formatter = logging.Formatter('[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s', '%d/%b/%Y %H:%M:%S')
-    ch.setFormatter(formatter)
-    fh.setFormatter(formatter)
-    # add the handlers to logger
-    logger.addHandler(ch)
-    logger.addHandler(fh)
 
 
 class RabbitMQ:
