@@ -921,4 +921,52 @@ def update_customer_apikey(customer_email, user_apikey):
                                     "user_apikey" :  user_apikey},
                            message_body='')
 
-    return value.decode("utf-8")
\ No newline at end of file
+    return value.decode("utf-8")
+
+def get_plan_details(plan_name):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'get_plan_details',
+                                    'plan_name': plan_name},
+                           message_body='')
+    value = value.decode('utf-8')
+    return value
+
+
+def update_plan_admin(plan_name, images_products, max_post, total):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'update_plan_admin',
+                                    'plan_name': plan_name,
+                                    'images_product': images_products,
+                                    'max_post': max_post,
+                                    'total': total},
+                           message_body='')
+    value = value.decode('utf-8')
+    return value
+
+
+def detect_objects_image(user_apikey, customer_name, customer_type, project_name, body, ip):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'user_apikey': user_apikey,
+                                    'operation': 'detect_objects_image',
+                                    'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'project_name': project_name,
+                                    'ip': ip
+                                    },
+                           message_body=body)
+    value = value.decode('utf-8')
+    list_value = value.replace('[', '').replace(']', '').split('}}, ')
+    list_bound_box = []
+    for probability in list_value:
+        probability = probability if probability.endswith('}}') else probability + "}}"
+        probability = json.loads(probability.replace("'", '"'))
+        list_bound_box.append(probability)
+
+    return list_bound_box
\ No newline at end of file
